====================================================
Miscellaneous utility functions
====================================================

This module contains utility functions to handle the convex hull, the occupancy
strings, the calculation data, the structure selection process and the spase-lm
estimators, etc.

.. toctree::
   :maxdepth: 1

   convex_hull
   duplicacy
   occu
   query
   selection
   sparselm
   supercells
   taskdoc
